/*
    This file is part of Contact Editor.

    SPDX-FileCopyrightText: 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
    SPDX-FileCopyrightText: 2016-2026 Laurent Montel <montel@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/
#pragma once

#include <QObject>

class CustomFielsListWidgetTest : public QObject
{
    Q_OBJECT
public:
    explicit CustomFielsListWidgetTest(QObject *parent = nullptr);
    ~CustomFielsListWidgetTest() override;
};
